@@ -1,4 +1,14 @@
 use crate::utils::distance_between;
+
+#[cfg(feature = "std")]
+use core::fmt::Debug;
+
+#[cfg(feature = "std")]
+use std::string::String;
+
+#[cfg(feature = "std")]
+use std::format;
+
 use core::intrinsics;
 use core::iter::{FusedIterator, TrustedLen};
 use core::marker::PhantomData;
@@ -17,6 +27,25 @@ pub struct StaticVecIterMut<'a, T: 'a> {
   pub(crate) marker: PhantomData<&'a mut T>,
 }
 
+impl<'a, T: 'a + Debug> StaticVecIterConst<'a, T> {
+  #[cfg(feature = "std")]
+  #[doc(cfg(feature = "std"))]
+  #[inline(always)]
+  ///Returns a string displaying the current values of the
+  ///iterator's `start` and `end` elements on two separate lines.
+  ///Locally requires that `T` implements [Debug](core::fmt::Debug)
+  ///to make it possible to pretty-print the elements.
+  pub fn bounds_to_string(&self) -> String {
+    //Safety: `start` and `end` are never null.
+    unsafe {
+      format!(
+        "Current value of `start`: {:?}\nCurrent value of `end`: {:?}",
+        *self.start, *self.end
+      )
+    }
+  }
+}
+
 impl<'a, T: 'a> Iterator for StaticVecIterConst<'a, T> {
   type Item = &'a T;
   #[inline(always)]
@@ -46,7 +75,7 @@ impl<'a, T: 'a> Iterator for StaticVecIterConst<'a, T> {
 impl<'a, T: 'a> DoubleEndedIterator for StaticVecIterConst<'a, T> {
   #[inline(always)]
   fn next_back(&mut self) -> Option<Self::Item> {
-    if self.end as usize > self.start as usize {
+    if (self.end as usize) > (self.start as usize) {
       unsafe {
         self.end = if intrinsics::size_of::<T>() == 0 {
           (self.end as usize - 1) as *const _
@@ -76,6 +105,25 @@ impl<'a, T: 'a> ExactSizeIterator for StaticVecIterConst<'a, T> {
 impl<'a, T: 'a> FusedIterator for StaticVecIterConst<'a, T> {}
 unsafe impl<'a, T: 'a> TrustedLen for StaticVecIterConst<'a, T> {}
 
+impl<'a, T: 'a + Debug> StaticVecIterMut<'a, T> {
+  #[cfg(feature = "std")]
+  #[doc(cfg(feature = "std"))]
+  #[inline(always)]
+  ///Returns a string displaying the current values of the
+  ///iterator's `start` and `end` elements on two separate lines.
+  ///Locally requires that `T` implements [Debug](core::fmt::Debug)
+  ///to make it possible to pretty-print the elements.
+  pub fn bounds_to_string(&self) -> String {
+    //Safety: `start` and `end` are never null.
+    unsafe {
+      format!(
+        "Current value of `start`: {:?}\nCurrent value of `end`: {:?}",
+        *self.start, *self.end
+      )
+    }
+  }
+}
+
 impl<'a, T: 'a> Iterator for StaticVecIterMut<'a, T> {
   type Item = &'a mut T;
   #[inline(always)]
@@ -105,7 +153,7 @@ impl<'a, T: 'a> Iterator for StaticVecIterMut<'a, T> {
 impl<'a, T: 'a> DoubleEndedIterator for StaticVecIterMut<'a, T> {
   #[inline(always)]
   fn next_back(&mut self) -> Option<Self::Item> {
-    if self.end as usize > self.start as usize {
+    if (self.end as usize) > (self.start as usize) {
       unsafe {
         self.end = if intrinsics::size_of::<T>() == 0 {
           (self.end as usize - 1) as *mut _
