@@ -29,6 +29,23 @@ fn as_slice() {
   assert_eq!(buffer.as_slice(), &[1, 2, 3, 5, 8]);
 }
 
+#[test]
+fn bounds_to_string() {
+  let mut v = staticvec![1, 2, 3, 4];
+  let mut it = v.iter();
+  it.next_back();
+  assert_eq!(
+    "Current value of `start`: 1\nCurrent value of `end`: 4",
+    it.bounds_to_string()
+  );
+  let mut itm = v.iter_mut();
+  itm.next_back();
+  assert_eq!(
+    "Current value of `start`: 1\nCurrent value of `end`: 4",
+    itm.bounds_to_string()
+  );
+}
+
 #[test]
 fn capacity() {
   let vec = StaticVec::<i32, 10>::new();
@@ -329,6 +346,8 @@ fn read_exact() {
   let mut buffer = [0, 0, 0, 0];
   ints.read_exact(&mut buffer).unwrap();
   assert_eq!(buffer, [1, 2, 3, 4]);
+  let mut buffer2 = [0, 0, 0, 0, 0, 0, 0, 0];
+  assert!(ints.read_exact(&mut buffer2).is_err());
 }
 
 #[cfg(feature = "std")]
